Getting Help
````````````

.. include:: includes/cli_help.rst

.. _basic_usage:

Basic Usage
```````````

.. include:: includes/cli_basic_usage.rst

.. _options:

Options and Arguments
`````````````````````

.. include:: includes/cli_opts_args.rst

.. _combining_options:

Combining Options
`````````````````

.. include:: includes/cli_combine_opts.rst

.. _common_usage:

Common Usage
````````````

Here are some common use cases for the linchpin command-line.

.. include:: includes/cli_common_usage.rst



